@@ -1,6 +1,7 @@
 from typing import Any
 from typing import Dict
 
-from .client import DefaultClient  #
+from .client import DefaultClient  # noqa
+
 
 RequestFixtures = Dict[str, Dict[str, Dict[str, Any]]]
